==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/cnd.asm/src/org/netbeans/modules/cnd/asm/core/ui/top/InstructionInfoPanel.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */


package org.netbeans.modules.cnd.asm.core.ui.top;

import java.util.Formatter;

import org.netbeans.modules.cnd.asm.model.lang.instruction.Instruction;
import org.netbeans.modules.cnd.asm.model.lang.instruction.InstructionArgs;

public class InstructionInfoPanel extends javax.swing.JPanel {
                  
    public InstructionInfoPanel() {
        initComponents();                
    }
    
    private String infoTemplate = "%s  -  %s\n"; // NOI18N
                                  
    
    public void setInstruction(Instruction instr) {
        StringBuilder res = new StringBuilder();
               
       res.append( 
           new Formatter().format(infoTemplate, instr.getName(),
                                  instr.getDescription()) 
        );
                       
        for (InstructionArgs arg : instr.getArguments()) {
            res.append("\n").append(instr.getName()); // NOI18N
            for (String mnemonic : arg.getParamMnemonic()) {
                res.append(" ").append(mnemonic); // NOI18N
            }
            res.append(" - ").append(arg.getDescription()); // NOI18N
        } 
        
        //jInfoTextArea.setDocument(new HTMLDocument());
        jInfoTextArea.setText(res.toString());        
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jInfoScrollPanel = new javax.swing.JScrollPane();
        jInfoTextArea = new javax.swing.JTextArea();

        setLayout(new javax.swing.BoxLayout(this, javax.swing.BoxLayout.Y_AXIS));

        jInfoTextArea.setColumns(50);
        jInfoTextArea.setRows(5);
        jInfoScrollPanel.setViewportView(jInfoTextArea);

        add(jInfoScrollPanel);
    }// </editor-fold>//GEN-END:initComponents
    
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JScrollPane jInfoScrollPanel;
    private javax.swing.JTextArea jInfoTextArea;
    // End of variables declaration//GEN-END:variables
    
}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/cnd.asm/src/org/netbeans/modules/cnd/asm/core/ui/top/InstructionInfoPanel.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */


package org.netbeans.modules.cnd.asm.core.ui.top;

import java.util.Formatter;

import org.netbeans.modules.cnd.asm.model.lang.instruction.Instruction;
import org.netbeans.modules.cnd.asm.model.lang.instruction.InstructionArgs;

public class InstructionInfoPanel extends javax.swing.JPanel {

    public InstructionInfoPanel() {
        initComponents();
    }

    private static final String infoTemplate = "%s  -  %s%n"; // NOI18N


    public void setInstruction(Instruction instr) {
        StringBuilder res = new StringBuilder();

       res.append(
           new Formatter().format(infoTemplate, instr.getName(),
                                  instr.getDescription())
        );

        for (InstructionArgs arg : instr.getArguments()) {
            res.append("\n").append(instr.getName()); // NOI18N
            for (String mnemonic : arg.getParamMnemonic()) {
                res.append(" ").append(mnemonic); // NOI18N
            }
            res.append(" - ").append(arg.getDescription()); // NOI18N
        }

        //jInfoTextArea.setDocument(new HTMLDocument());
        jInfoTextArea.setText(res.toString());
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jInfoScrollPanel = new javax.swing.JScrollPane();
        jInfoTextArea = new javax.swing.JTextArea();

        setLayout(new javax.swing.BoxLayout(this, javax.swing.BoxLayout.Y_AXIS));

        jInfoTextArea.setColumns(50);
        jInfoTextArea.setRows(5);
        jInfoScrollPanel.setViewportView(jInfoTextArea);

        add(jInfoScrollPanel);
    }// </editor-fold>//GEN-END:initComponents


    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JScrollPane jInfoScrollPanel;
    private javax.swing.JTextArea jInfoTextArea;
    // End of variables declaration//GEN-END:variables

}
